@@ -1,7 +1,6 @@
 import os.path
 
 from dslibrary.sql.file_sql_wr import file_sql_write
-from dslibrary.transport.to_local import DSLibraryLocal
 from dslibrary.utils.dbconn import Connection
 from dslibrary.utils.file_utils import is_breakout_path, join_uri_path
 from dslibrary import _DEFAULT
@@ -41,7 +40,8 @@ def connect_to_folder_as_database(folder: str, for_write: bool=False, sql_flavor
         df = dsl.sql_select(sql, parameters, table_loader=table_reader, **kwargs)
         rows = df.itertuples(index=False, name=None)
         # TODO iteration in chunks would make more efficient use of memory - see read_more below
-        return list(df.columns), list(rows), None
+        # name, type_code, display_size, internal_size, precision, scale, null_ok
+        return [[col, str(dtype), None, None, None, None, True] for col, dtype in zip(df.columns, df.dtypes)], list(rows), None
     def write(sql, parameters):
         file_sql_write(table_writer, sql, parameters)
     return Connection(read=read, write=write if for_write else None, read_more=None, flavor=sql_flavor)
