@@ -411,7 +411,7 @@ class TestFront(unittest.TestCase):
         """
         inst = DSLibrary()
         log = []
-        with mock.patch("dslibrary.front.connect_to_database", lambda **k: log.append(k) or "NoSqlConn"):
+        with mock.patch("dslibrary.front.connect_to_database", lambda dsl, **k: log.append(k) or "NoSqlConn"):
             fs = inst.get_sql_connection("resource", for_write=True, arg1=123)
             self.assertEqual(fs, "NoSqlConn")
         self.assertEqual(log, [{'uri': 'resource', 'library': None, 'for_write': True, 'arg1': 123}])
